# ssdk-alpha-ti
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 0.0.2
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ssdk_alpha_ti
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ssdk_alpha_ti
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import ssdk_alpha_ti
from ssdk_alpha_ti.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://wqpuo37v9e.execute-api.us-east-1.amazonaws.com/api
# See configuration.py for a list of all supported configuration parameters.
configuration = ssdk_alpha_ti.Configuration(
    host = "https://wqpuo37v9e.execute-api.us-east-1.amazonaws.com/api"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tenant_authorizer
configuration.api_key['tenant_authorizer'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tenant_authorizer'] = 'Bearer'


# Enter a context with an instance of the API client
with ssdk_alpha_ti.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ssdk_alpha_ti.BrandApi(api_client)
    tenant_id = 'tenant_id_example' # str | 
    brand_id = 'brand_id_example' # str | 

    try:
        # Get the latest brand compass
        api_instance.tenant_tenant_id_brand_brand_id_compass_get(tenant_id, brand_id)
    except ApiException as e:
        print("Exception when calling BrandApi->tenant_tenant_id_brand_brand_id_compass_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://wqpuo37v9e.execute-api.us-east-1.amazonaws.com/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BrandApi* | [**tenant_tenant_id_brand_brand_id_compass_get**](docs/BrandApi.md#tenant_tenant_id_brand_brand_id_compass_get) | **GET** /tenant/{tenant_id}/brand/{brand_id}/compass | Get the latest brand compass
*BrandApi* | [**tenant_tenant_id_brand_brand_id_compass_trigger_post**](docs/BrandApi.md#tenant_tenant_id_brand_brand_id_compass_trigger_post) | **POST** /tenant/{tenant_id}/brand/{brand_id}/compass/trigger | Trigger the generation of a brand compass
*BrandApi* | [**tenant_tenant_id_brand_brand_id_delete**](docs/BrandApi.md#tenant_tenant_id_brand_brand_id_delete) | **DELETE** /tenant/{tenant_id}/brand/{brand_id} | Delete a brand
*BrandApi* | [**tenant_tenant_id_brand_brand_id_get**](docs/BrandApi.md#tenant_tenant_id_brand_brand_id_get) | **GET** /tenant/{tenant_id}/brand/{brand_id} | Get brand details
*BrandApi* | [**tenant_tenant_id_brand_brand_id_put**](docs/BrandApi.md#tenant_tenant_id_brand_brand_id_put) | **PUT** /tenant/{tenant_id}/brand/{brand_id} | Update brand details
*BrandApi* | [**tenant_tenant_id_brand_get**](docs/BrandApi.md#tenant_tenant_id_brand_get) | **GET** /tenant/{tenant_id}/brand | List all active brands for a tenant
*BrandApi* | [**tenant_tenant_id_brand_post**](docs/BrandApi.md#tenant_tenant_id_brand_post) | **POST** /tenant/{tenant_id}/brand | Create a new brand for a tenant
*GenerationApi* | [**tenant_tenant_id_brand_brand_id_worker_worker_id_generation_generation_id_get**](docs/GenerationApi.md#tenant_tenant_id_brand_brand_id_worker_worker_id_generation_generation_id_get) | **GET** /tenant/{tenant_id}/brand/{brand_id}/worker/{worker_id}/generation/{generation_id} | Get generation details
*GenerationApi* | [**tenant_tenant_id_brand_brand_id_worker_worker_id_generation_get**](docs/GenerationApi.md#tenant_tenant_id_brand_brand_id_worker_worker_id_generation_get) | **GET** /tenant/{tenant_id}/brand/{brand_id}/worker/{worker_id}/generation | List all generations for a brand and worker
*GenerationApi* | [**tenant_tenant_id_brand_brand_id_worker_worker_id_generation_post**](docs/GenerationApi.md#tenant_tenant_id_brand_brand_id_worker_worker_id_generation_post) | **POST** /tenant/{tenant_id}/brand/{brand_id}/worker/{worker_id}/generation | Start a generation process
*HealthcheckApi* | [**healthcheck_get**](docs/HealthcheckApi.md#healthcheck_get) | **GET** /healthcheck | 
*PromptApi* | [**tenant_tenant_id_prompt_get**](docs/PromptApi.md#tenant_tenant_id_prompt_get) | **GET** /tenant/{tenant_id}/prompt | List all active prompts for a tenant
*PromptApi* | [**tenant_tenant_id_prompt_post**](docs/PromptApi.md#tenant_tenant_id_prompt_post) | **POST** /tenant/{tenant_id}/prompt | Create a new prompt for a tenant
*PromptApi* | [**tenant_tenant_id_prompt_prompt_id_delete**](docs/PromptApi.md#tenant_tenant_id_prompt_prompt_id_delete) | **DELETE** /tenant/{tenant_id}/prompt/{prompt_id} | Delete a prompt
*PromptApi* | [**tenant_tenant_id_prompt_prompt_id_get**](docs/PromptApi.md#tenant_tenant_id_prompt_prompt_id_get) | **GET** /tenant/{tenant_id}/prompt/{prompt_id} | Get prompt details
*PromptApi* | [**tenant_tenant_id_prompt_prompt_id_put**](docs/PromptApi.md#tenant_tenant_id_prompt_prompt_id_put) | **PUT** /tenant/{tenant_id}/prompt/{prompt_id} | Update prompt details
*SourceApi* | [**tenant_tenant_id_brand_brand_id_source_get**](docs/SourceApi.md#tenant_tenant_id_brand_brand_id_source_get) | **GET** /tenant/{tenant_id}/brand/{brand_id}/source | List sources for a brand
*SourceApi* | [**tenant_tenant_id_brand_brand_id_source_post**](docs/SourceApi.md#tenant_tenant_id_brand_brand_id_source_post) | **POST** /tenant/{tenant_id}/brand/{brand_id}/source | Create a new source for a brand
*SourceApi* | [**tenant_tenant_id_brand_brand_id_source_source_id_delete**](docs/SourceApi.md#tenant_tenant_id_brand_brand_id_source_source_id_delete) | **DELETE** /tenant/{tenant_id}/brand/{brand_id}/source/{source_id} | Delete a source and its associated data
*SourceApi* | [**tenant_tenant_id_brand_brand_id_source_source_id_get**](docs/SourceApi.md#tenant_tenant_id_brand_brand_id_source_source_id_get) | **GET** /tenant/{tenant_id}/brand/{brand_id}/source/{source_id} | Get source details
*SourceApi* | [**tenant_tenant_id_brand_brand_id_source_source_id_reprocess_post**](docs/SourceApi.md#tenant_tenant_id_brand_brand_id_source_source_id_reprocess_post) | **POST** /tenant/{tenant_id}/brand/{brand_id}/source/{source_id}/reprocess | Reprocess a source
*SwaggerApi* | [**swagger_get**](docs/SwaggerApi.md#swagger_get) | **GET** /swagger | 
*TenantApi* | [**tenant_tenant_id_delete**](docs/TenantApi.md#tenant_tenant_id_delete) | **DELETE** /tenant/{tenant_id} | Delete a tenant
*TenantApi* | [**tenant_tenant_id_get**](docs/TenantApi.md#tenant_tenant_id_get) | **GET** /tenant/{tenant_id} | Get tenant details
*TenantApi* | [**tenant_tenant_id_put**](docs/TenantApi.md#tenant_tenant_id_put) | **PUT** /tenant/{tenant_id} | Update tenant details
*WorkerApi* | [**tenant_tenant_id_worker_get**](docs/WorkerApi.md#tenant_tenant_id_worker_get) | **GET** /tenant/{tenant_id}/worker | List all workers for a brand
*WorkerApi* | [**tenant_tenant_id_worker_post**](docs/WorkerApi.md#tenant_tenant_id_worker_post) | **POST** /tenant/{tenant_id}/worker | Create a new worker request
*WorkerApi* | [**tenant_tenant_id_worker_worker_id_delete**](docs/WorkerApi.md#tenant_tenant_id_worker_worker_id_delete) | **DELETE** /tenant/{tenant_id}/worker/{worker_id} | Delete an existing worker
*WorkerApi* | [**tenant_tenant_id_worker_worker_id_get**](docs/WorkerApi.md#tenant_tenant_id_worker_worker_id_get) | **GET** /tenant/{tenant_id}/worker/{worker_id} | Get worker details
*WorkerApi* | [**tenant_tenant_id_worker_worker_id_put**](docs/WorkerApi.md#tenant_tenant_id_worker_worker_id_put) | **PUT** /tenant/{tenant_id}/worker/{worker_id} | Update an existing worker
*DefaultApi* | [**healthcheck_options**](docs/DefaultApi.md#healthcheck_options) | **OPTIONS** /healthcheck | 


## Documentation For Models

 - [BrandCompassProgressSchema](docs/BrandCompassProgressSchema.md)
 - [BrandCompassResponseSchema](docs/BrandCompassResponseSchema.md)
 - [BrandCreateSchema](docs/BrandCreateSchema.md)
 - [BrandResponseSchema](docs/BrandResponseSchema.md)
 - [BrandUpdateSchema](docs/BrandUpdateSchema.md)
 - [GenerationCreateSchema](docs/GenerationCreateSchema.md)
 - [GenerationResponseSchema](docs/GenerationResponseSchema.md)
 - [PromptCreateSchema](docs/PromptCreateSchema.md)
 - [PromptResponseSchema](docs/PromptResponseSchema.md)
 - [PromptUpdateSchema](docs/PromptUpdateSchema.md)
 - [SourceResponseSchema](docs/SourceResponseSchema.md)
 - [TenantCreateSchema](docs/TenantCreateSchema.md)
 - [TenantResponseSchema](docs/TenantResponseSchema.md)
 - [TenantSettingsSchema](docs/TenantSettingsSchema.md)
 - [TenantUpdateSchema](docs/TenantUpdateSchema.md)
 - [WorkerCreateSchema](docs/WorkerCreateSchema.md)
 - [WorkerResponseSchema](docs/WorkerResponseSchema.md)
 - [WorkerUpdateSchema](docs/WorkerUpdateSchema.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="tenant_authorizer"></a>
### tenant_authorizer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




